Description: fixed spelling errors
 Upstream contains some typos in source and the po files, lintian
 catches it. This patch is fixed.
Author: Ervin Hegedus <airween@gmail.com>
--- a/po/de.po
+++ b/po/de.po
@@ -257,7 +257,7 @@
 msgstr "Kei_n Debug"
 
 #: src/grig-menubar.c:91
-msgid "Don't show any debug mesages"
+msgid "Don't show any debug messages"
 msgstr "Keine Debug-Mitteilungen anzeigen"
 
 #: src/grig-menubar.c:92
--- a/po/fr.po
+++ b/po/fr.po
@@ -239,7 +239,7 @@
 msgstr "_Aucun débogage"
 
 #: src/grig-menubar.c:91
-msgid "Don't show any debug mesages"
+msgid "Don't show any debug messages"
 msgstr "Ne pas afficher les messages de débogage"
 
 #: src/grig-menubar.c:92
--- a/po/grig.pot
+++ b/po/grig.pot
@@ -232,7 +232,7 @@
 msgstr ""
 
 #: src/grig-menubar.c:91
-msgid "Don't show any debug mesages"
+msgid "Don't show any debug messages"
 msgstr ""
 
 #: src/grig-menubar.c:92
--- a/po/tr.po
+++ b/po/tr.po
@@ -236,7 +236,7 @@
 msgstr ""
 
 #: src/grig-menubar.c:91
-msgid "Don't show any debug mesages"
+msgid "Don't show any debug messages"
 msgstr ""
 
 #: src/grig-menubar.c:92
--- a/src/grig-menubar.c
+++ b/src/grig-menubar.c
@@ -88,7 +88,7 @@
 
 /** \brief Radio items for selectinghamlib debug level. */
 static GtkRadioActionEntry radio_entries[] = {
-  { "None",    NULL, N_("_No Debug"), NULL, N_("Don't show any debug mesages"),                0 },
+  { "None",    NULL, N_("_No Debug"), NULL, N_("Don't show any debug messages"),               0 },
   { "Bug",     NULL, N_("_Bug"),      NULL, N_("Show error messages caused by possible bugs"), 1 },
   { "Error",   NULL, N_("_Error"),    NULL, N_("Show run-time error messages"),                2 },
   { "Warn",    NULL, N_("_Warning"),  NULL, N_("Show warnings"),                               3 },
--- grig-0.8.1.orig/doc/man/grig.1.in
+++ grig-0.8.1/doc/man/grig.1.in
@@ -159,7 +159,7 @@ using the \-P or \-\-enable\-pwr command
 PTT Control
 Similar to the power state, the PTT has caused strange behaviour on some radios.
 Consequently, it has been disabled by default but can be enabled using the \-p or
-\-\-enable\-ptt command line aguments.
+\-\-enable\-ptt command line arguments.
 
 .SH "AUTHOR"
 Written by Alexandru Csete, OZ9AEC.
--- grig-0.8.1.orig/src/rig-daemon.c
+++ grig-0.8.1/src/rig-daemon.c
@@ -608,7 +608,7 @@ rig_daemon_start       (int          rig
 #endif
 
 	grig_debug_local (RIG_DEBUG_TRACE,
-			  _("%s: Init successfull, executing post-init"),
+			  _("%s: Init successful, executing post-init"),
 			  __FUNCTION__);
 
 	/* get capabilities and settings  */
@@ -1115,7 +1115,7 @@ rig_daemon_cycle_cb  (gpointer data)
  * This function is responsible for the execution of the specified rig command.
  * First, it checks whether the command is supported by the current radio, if yes,
  * it executes the corresponding hamlib API call. If the command execution is not
  * successfull, an anomaly report is sent to the rig error manager which will take
  * care of any further actions like disabling repeatedly failing commands.
  *
  * \note The 'get' commands use local buffers for the acquired value and do not
@@ -1115,7 +1115,7 @@ rig_daemon_cycle_cb  (gpointer data)
  * First, it checks whether the command is supported by the current radio, if yes,
  * it executes the corresponding hamlib API call. If the command execution is not
- * successfull, an anomaly report is sent to the rig error manager which will take
+ * successful, an anomaly report is sent to the rig error manager which will take
  * care of any further actions like disabling repeatedly failing commands.
  *
